==> coding_buddy-0.0.3.tar.gz: lib/logic/service/api_service.dart <==
import 'package:dio/dio.dart';
import 'package:coding_buddy/coding_buddy.dart' as Core;
import 'package:coding_buddy/logic/helper/debug_utils.dart';

enum MethodRequest { POST, GET, PUT, DELETE }

class CBApiService {
  Dio _dio = Dio();

  CBApiService(String baseUrl) {
    _dio.options.baseUrl = baseUrl;
    _dio.options.connectTimeout = 90000; //90s
    _dio.options.receiveTimeout = 10000;
    _dio.options.headers = {'Accept': 'application/json'};
  }

  Future<Response> call(String url,
      {MethodRequest method = MethodRequest.POST,
      Map<String, dynamic> request,
      Map<String, String> header,
      String token,
      bool useFormData = true}) async {
    if (header != null) {
      _dio.options.headers = header;
    }
    if (token != null) {
      if (header != null) {
        header.addAll({'Authorization': 'Bearer $token'});
        _dio.options.headers = header;
      } else {
        _dio.options.headers = {
          'Accept': 'application/json',
          'Authorization': 'Bearer $token'
        };
      }
      if (method == MethodRequest.PUT) {
        _dio.options.headers = {
          'Accept': 'application/json',
          'Content-Type': 'application/x-www-form-urlencoded',
          'Authorization': 'Bearer $token',
        };
      }
    }

    printDebug('URL : ${_dio.options.baseUrl}$url');
    printDebug('Method : $method');
    printDebug("Header : ${_dio.options.headers}");
    printDebug("Request : $request");

    var selectedMethod;
    try {
      Response response;
      switch (method) {
        case MethodRequest.GET:
          selectedMethod = method;
          response = await _dio.get(url, queryParameters: request);
          break;
        case MethodRequest.PUT:
          selectedMethod = method;
          response = await _dio.put(
            url,
            data: useFormData ? FormData.fromMap(request) : request,
          );
          break;
        case MethodRequest.DELETE:
          selectedMethod = method;
          response = await _dio.delete(
            url,
            data: useFormData ? FormData.fromMap(request) : request,
          );
          break;
        default:
          selectedMethod = MethodRequest.POST;
          response = await _dio.post(
            url,
            data: useFormData ? FormData.fromMap(request) : request,
          );
      }
      printDebug('Success $selectedMethod $url: \nResponse : ${response.data}');
      return response;
    } on DioError catch (e) {
      printDebug('Error $selectedMethod $url: $e\nData: ${e.response?.data}');
      if (e.response?.data is Map) {
        (e.response.data as Map).addAll(<String, dynamic>{
          "status": "error",
        });
        Core.CodingBuddy.defaultErrorHandler(e.response);
        return e.response;
      } else {
        Response response = Response(data: {
          //TODO change message to multi langauge
          "message": "Terjadi kesalahan, coba lagi beberapa saat",
          "status": "error",
        });
        Core.CodingBuddy.defaultErrorHandler(response);
        return response;
      }
    }
  }
}

==> coding_buddy-0.0.5.tar.gz: lib/logic/service/api_service.dart <==
import 'package:dio/dio.dart';
import 'package:coding_buddy/coding_buddy.dart' as Core;
import 'package:coding_buddy/logic/helper/debug_utils.dart';

enum MethodRequest { POST, GET, PUT, DELETE }

class CBApiService {
  Dio _dio = Dio();

  CBApiService(String baseUrl) {
    _dio.options.baseUrl = baseUrl;
    _dio.options.connectTimeout = 90000; //90s
    _dio.options.receiveTimeout = 10000;
    _dio.options.headers = {'Accept': 'application/json'};
  }

  Future<Response> call(String url,
      {MethodRequest method = MethodRequest.POST,
      Map<String, dynamic> request,
      Map<String, String> header,
      String token,
      bool useFormData = false}) async {
    if (header != null) {
      _dio.options.headers = header;
    }
    if (token != null) {
      if (header != null) {
        header.addAll({'Authorization': 'Bearer $token'});
        _dio.options.headers = header;
      } else {
        _dio.options.headers = {
          'Accept': 'application/json',
          'Authorization': 'Bearer $token'
        };
      }
      if (method == MethodRequest.PUT) {
        _dio.options.headers = {
          'Accept': 'application/json',
          'Content-Type': 'application/x-www-form-urlencoded',
          'Authorization': 'Bearer $token',
        };
      }
    }

    printDebug('URL : ${_dio.options.baseUrl}$url');
    printDebug('Method : $method');
    printDebug("Header : ${_dio.options.headers}");
    printDebug("Request : $request");

    var selectedMethod;
    try {
      Response response;
      switch (method) {
        case MethodRequest.GET:
          selectedMethod = method;
          response = await _dio.get(url, queryParameters: request);
          break;
        case MethodRequest.PUT:
          selectedMethod = method;
          response = await _dio.put(
            url,
            data: useFormData ? FormData.fromMap(request) : request,
          );
          break;
        case MethodRequest.DELETE:
          selectedMethod = method;
          response = await _dio.delete(
            url,
            data: useFormData ? FormData.fromMap(request) : request,
          );
          break;
        default:
          selectedMethod = MethodRequest.POST;
          response = await _dio.post(
            url,
            data: useFormData ? FormData.fromMap(request) : request,
          );
      }
      printDebug('Success $selectedMethod $url: \nResponse : ${response.data}');
      return response;
    } on DioError catch (e) {
      printDebug('Error $selectedMethod $url: $e\nData: ${e.response?.data}');
      if (e.response?.data is Map) {
        (e.response.data as Map).addAll(<String, dynamic>{
          "status": "error",
        });
        Core.CodingBuddy.defaultErrorHandler(e.response);
        return e.response;
      } else {
        Response response = Response(data: {
          //TODO change message to multi langauge
          "message": "Terjadi kesalahan, coba lagi beberapa saat",
          "status": "error",
        });
        Core.CodingBuddy.defaultErrorHandler(response);
        return response;
      }
    }
  }
}
